<?php

return [
    'Zones' => [
        0 => 'Africa/Abidjan',
        1 => 'Africa/Accra',
        2 => 'Africa/Addis_Ababa',
        3 => 'Africa/Algiers',
        4 => 'Africa/Asmera',
        5 => 'Africa/Bamako',
        6 => 'Africa/Bangui',
        7 => 'Africa/Banjul',
        8 => 'Africa/Bissau',
        9 => 'Africa/Blantyre',
        10 => 'Africa/Brazzaville',
        11 => 'Africa/Bujumbura',
        12 => 'Africa/Cairo',
        13 => 'Africa/Casablanca',
        14 => 'Africa/Ceuta',
        15 => 'Africa/Conakry',
        16 => 'Africa/Dakar',
        17 => 'Africa/Dar_es_Salaam',
        18 => 'Africa/Djibouti',
        19 => 'Africa/Douala',
        20 => 'Africa/El_Aaiun',
        21 => 'Africa/Freetown',
        22 => 'Africa/Gaborone',
        23 => 'Africa/Harare',
        24 => 'Africa/Johannesburg',
        25 => 'Africa/Juba',
        26 => 'Africa/Kampala',
        27 => 'Africa/Khartoum',
        28 => 'Africa/Kigali',
        29 => 'Africa/Kinshasa',
        30 => 'Africa/Lagos',
        31 => 'Africa/Libreville',
        32 => 'Africa/Lome',
        33 => 'Africa/Luanda',
        34 => 'Africa/Lubumbashi',
        35 => 'Africa/Lusaka',
        36 => 'Africa/Malabo',
        37 => 'Africa/Maputo',
        38 => 'Africa/Maseru',
        39 => 'Africa/Mbabane',
        40 => 'Africa/Mogadishu',
        41 => 'Africa/Monrovia',
        42 => 'Africa/Nairobi',
        43 => 'Africa/Ndjamena',
        44 => 'Africa/Niamey',
        45 => 'Africa/Nouakchott',
        46 => 'Africa/Ouagadougou',
        47 => 'Africa/Porto-Novo',
        48 => 'Africa/Sao_Tome',
        49 => 'Africa/Tripoli',
        50 => 'Africa/Tunis',
        51 => 'Africa/Windhoek',
        52 => 'America/Adak',
        53 => 'America/Anchorage',
        54 => 'America/Anguilla',
        55 => 'America/Antigua',
        56 => 'America/Araguaina',
        57 => 'America/Argentina/La_Rioja',
        58 => 'America/Argentina/Rio_Gallegos',
        59 => 'America/Argentina/Salta',
        60 => 'America/Argentina/San_Juan',
        61 => 'America/Argentina/San_Luis',
        62 => 'America/Argentina/Tucuman',
        63 => 'America/Argentina/Ushuaia',
        64 => 'America/Aruba',
        65 => 'America/Asuncion',
        66 => 'America/Bahia',
        67 => 'America/Bahia_Banderas',
        68 => 'America/Barbados',
        69 => 'America/Belem',
        70 => 'America/Belize',
        71 => 'America/Blanc-Sablon',
        72 => 'America/Boa_Vista',
        73 => 'America/Bogota',
        74 => 'America/Boise',
        75 => 'America/Buenos_Aires',
        76 => 'America/Cambridge_Bay',
        77 => 'America/Campo_Grande',
        78 => 'America/Cancun',
        79 => 'America/Caracas',
        80 => 'America/Catamarca',
        81 => 'America/Cayenne',
        82 => 'America/Cayman',
        83 => 'America/Chicago',
        84 => 'America/Chihuahua',
        85 => 'America/Ciudad_Juarez',
        86 => 'America/Coral_Harbour',
        87 => 'America/Cordoba',
        88 => 'America/Costa_Rica',
        89 => 'America/Creston',
        90 => 'America/Cuiaba',
        91 => 'America/Curacao',
        92 => 'America/Danmarkshavn',
        93 => 'America/Dawson',
        94 => 'America/Dawson_Creek',
        95 => 'America/Denver',
        96 => 'America/Detroit',
        97 => 'America/Dominica',
        98 => 'America/Edmonton',
        99 => 'America/Eirunepe',
        100 => 'America/El_Salvador',
        101 => 'America/Fort_Nelson',
        102 => 'America/Fortaleza',
        103 => 'America/Glace_Bay',
        104 => 'America/Godthab',
        105 => 'America/Goose_Bay',
        106 => 'America/Grand_Turk',
        107 => 'America/Grenada',
        108 => 'America/Guadeloupe',
        109 => 'America/Guatemala',
        110 => 'America/Guayaquil',
        111 => 'America/Guyana',
        112 => 'America/Halifax',
        113 => 'America/Havana',
        114 => 'America/Hermosillo',
        115 => 'America/Indiana/Knox',
        116 => 'America/Indiana/Marengo',
        117 => 'America/Indiana/Petersburg',
        118 => 'America/Indiana/Tell_City',
        119 => 'America/Indiana/Vevay',
        120 => 'America/Indiana/Vincennes',
        121 => 'America/Indiana/Winamac',
        122 => 'America/Indianapolis',
        123 => 'America/Inuvik',
        124 => 'America/Iqaluit',
        125 => 'America/Jamaica',
        126 => 'America/Jujuy',
        127 => 'America/Juneau',
        128 => 'America/Kentucky/Monticello',
        129 => 'America/Kralendijk',
        130 => 'America/La_Paz',
        131 => 'America/Lima',
        132 => 'America/Los_Angeles',
        133 => 'America/Louisville',
        134 => 'America/Lower_Princes',
        135 => 'America/Maceio',
        136 => 'America/Managua',
        137 => 'America/Manaus',
        138 => 'America/Marigot',
        139 => 'America/Martinique',
        140 => 'America/Matamoros',
        141 => 'America/Mazatlan',
        142 => 'America/Mendoza',
        143 => 'America/Menominee',
        144 => 'America/Merida',
        145 => 'America/Metlakatla',
        146 => 'America/Mexico_City',
        147 => 'America/Miquelon',
        148 => 'America/Moncton',
        149 => 'America/Monterrey',
        150 => 'America/Montevideo',
        151 => 'America/Montserrat',
        152 => 'America/Nassau',
        153 => 'America/New_York',
        154 => 'America/Nipigon',
        155 => 'America/Nome',
        156 => 'America/Noronha',
        157 => 'America/North_Dakota/Beulah',
        158 => 'America/North_Dakota/Center',
        159 => 'America/North_Dakota/New_Salem',
        160 => 'America/Ojinaga',
        161 => 'America/Panama',
        162 => 'America/Pangnirtung',
        163 => 'America/Paramaribo',
        164 => 'America/Phoenix',
        165 => 'America/Port-au-Prince',
        166 => 'America/Port_of_Spain',
        167 => 'America/Porto_Velho',
        168 => 'America/Puerto_Rico',
        169 => 'America/Punta_Arenas',
        170 => 'America/Rainy_River',
        171 => 'America/Rankin_Inlet',
        172 => 'America/Recife',
        173 => 'America/Regina',
        174 => 'America/Resolute',
        175 => 'America/Rio_Branco',
        176 => 'America/Santa_Isabel',
        177 => 'America/Santarem',
        178 => 'America/Santiago',
        179 => 'America/Santo_Domingo',
        180 => 'America/Sao_Paulo',
        181 => 'America/Scoresbysund',
        182 => 'America/Sitka',
        183 => 'America/St_Barthelemy',
        184 => 'America/St_Johns',
        185 => 'America/St_Kitts',
        186 => 'America/St_Lucia',
        187 => 'America/St_Thomas',
        188 => 'America/St_Vincent',
        189 => 'America/Swift_Current',
        190 => 'America/Tegucigalpa',
        191 => 'America/Thule',
        192 => 'America/Thunder_Bay',
        193 => 'America/Tijuana',
        194 => 'America/Toronto',
        195 => 'America/Tortola',
        196 => 'America/Vancouver',
        197 => 'America/Whitehorse',
        198 => 'America/Winnipeg',
        199 => 'America/Yakutat',
        200 => 'America/Yellowknife',
        201 => 'Antarctica/Casey',
        202 => 'Antarctica/Davis',
        203 => 'Antarctica/DumontDUrville',
        204 => 'Antarctica/Macquarie',
        205 => 'Antarctica/Mawson',
        206 => 'Antarctica/McMurdo',
        207 => 'Antarctica/Palmer',
        208 => 'Antarctica/Rothera',
        209 => 'Antarctica/Syowa',
        210 => 'Antarctica/Troll',
        211 => 'Antarctica/Vostok',
        212 => 'Arctic/Longyearbyen',
        213 => 'Asia/Aden',
        214 => 'Asia/Almaty',
        215 => 'Asia/Amman',
        216 => 'Asia/Anadyr',
        217 => 'Asia/Aqtau',
        218 => 'Asia/Aqtobe',
        219 => 'Asia/Ashgabat',
        220 => 'Asia/Atyrau',
        221 => 'Asia/Baghdad',
        222 => 'Asia/Bahrain',
        223 => 'Asia/Baku',
        224 => 'Asia/Bangkok',
        225 => 'Asia/Barnaul',
        226 => 'Asia/Beirut',
        227 => 'Asia/Bishkek',
        228 => 'Asia/Brunei',
        229 => 'Asia/Calcutta',
        230 => 'Asia/Chita',
        231 => 'Asia/Choibalsan',
        232 => 'Asia/Colombo',
        233 => 'Asia/Damascus',
        234 => 'Asia/Dhaka',
        235 => 'Asia/Dili',
        236 => 'Asia/Dubai',
        237 => 'Asia/Dushanbe',
        238 => 'Asia/Famagusta',
        239 => 'Asia/Gaza',
        240 => 'Asia/Hebron',
        241 => 'Asia/Hong_Kong',
        242 => 'Asia/Hovd',
        243 => 'Asia/Irkutsk',
        244 => 'Asia/Jakarta',
        245 => 'Asia/Jayapura',
        246 => 'Asia/Jerusalem',
        247 => 'Asia/Kabul',
        248 => 'Asia/Kamchatka',
        249 => 'Asia/Karachi',
        250 => 'Asia/Katmandu',
        251 => 'Asia/Khandyga',
        252 => 'Asia/Krasnoyarsk',
        253 => 'Asia/Kuala_Lumpur',
        254 => 'Asia/Kuching',
        255 => 'Asia/Kuwait',
        256 => 'Asia/Macau',
        257 => 'Asia/Magadan',
        258 => 'Asia/Makassar',
        259 => 'Asia/Manila',
        260 => 'Asia/Muscat',
        261 => 'Asia/Nicosia',
        262 => 'Asia/Novokuznetsk',
        263 => 'Asia/Novosibirsk',
        264 => 'Asia/Omsk',
        265 => 'Asia/Oral',
        266 => 'Asia/Phnom_Penh',
        267 => 'Asia/Pontianak',
        268 => 'Asia/Pyongyang',
        269 => 'Asia/Qatar',
        270 => 'Asia/Qostanay',
        271 => 'Asia/Qyzylorda',
        272 => 'Asia/Rangoon',
        273 => 'Asia/Riyadh',
        274 => 'Asia/Saigon',
        275 => 'Asia/Sakhalin',
        276 => 'Asia/Samarkand',
        277 => 'Asia/Seoul',
        278 => 'Asia/Shanghai',
        279 => 'Asia/Singapore',
        280 => 'Asia/Srednekolymsk',
        281 => 'Asia/Taipei',
        282 => 'Asia/Tashkent',
        283 => 'Asia/Tbilisi',
        284 => 'Asia/Tehran',
        285 => 'Asia/Thimphu',
        286 => 'Asia/Tokyo',
        287 => 'Asia/Tomsk',
        288 => 'Asia/Ulaanbaatar',
        289 => 'Asia/Urumqi',
        290 => 'Asia/Ust-Nera',
        291 => 'Asia/Vientiane',
        292 => 'Asia/Vladivostok',
        293 => 'Asia/Yakutsk',
        294 => 'Asia/Yekaterinburg',
        295 => 'Asia/Yerevan',
        296 => 'Atlantic/Azores',
        297 => 'Atlantic/Bermuda',
        298 => 'Atlantic/Canary',
        299 => 'Atlantic/Cape_Verde',
        300 => 'Atlantic/Faeroe',
        301 => 'Atlantic/Madeira',
        302 => 'Atlantic/Reykjavik',
        303 => 'Atlantic/South_Georgia',
        304 => 'Atlantic/St_Helena',
        305 => 'Atlantic/Stanley',
        306 => 'Australia/Adelaide',
        307 => 'Australia/Brisbane',
        308 => 'Australia/Broken_Hill',
        309 => 'Australia/Currie',
        310 => 'Australia/Darwin',
        311 => 'Australia/Eucla',
        312 => 'Australia/Hobart',
        313 => 'Australia/Lindeman',
        314 => 'Australia/Lord_Howe',
        315 => 'Australia/Melbourne',
        316 => 'Australia/Perth',
        317 => 'Australia/Sydney',
        318 => 'CST6CDT',
        319 => 'EST5EDT',
        320 => 'Etc/GMT',
        321 => 'Etc/UTC',
        322 => 'Europe/Amsterdam',
        323 => 'Europe/Andorra',
        324 => 'Europe/Astrakhan',
        325 => 'Europe/Athens',
        326 => 'Europe/Belgrade',
        327 => 'Europe/Berlin',
        328 => 'Europe/Bratislava',
        329 => 'Europe/Brussels',
        330 => 'Europe/Bucharest',
        331 => 'Europe/Budapest',
        332 => 'Europe/Busingen',
        333 => 'Europe/Chisinau',
        334 => 'Europe/Copenhagen',
        335 => 'Europe/Dublin',
        336 => 'Europe/Gibraltar',
        337 => 'Europe/Guernsey',
        338 => 'Europe/Helsinki',
        339 => 'Europe/Isle_of_Man',
        340 => 'Europe/Istanbul',
        341 => 'Europe/Jersey',
        342 => 'Europe/Kaliningrad',
        343 => 'Europe/Kiev',
        344 => 'Europe/Kirov',
        345 => 'Europe/Lisbon',
        346 => 'Europe/Ljubljana',
        347 => 'Europe/London',
        348 => 'Europe/Luxembourg',
        349 => 'Europe/Madrid',
        350 => 'Europe/Malta',
        351 => 'Europe/Mariehamn',
        352 => 'Europe/Minsk',
        353 => 'Europe/Monaco',
        354 => 'Europe/Moscow',
        355 => 'Europe/Oslo',
        356 => 'Europe/Paris',
        357 => 'Europe/Podgorica',
        358 => 'Europe/Prague',
        359 => 'Europe/Riga',
        360 => 'Europe/Rome',
        361 => 'Europe/Samara',
        362 => 'Europe/San_Marino',
        363 => 'Europe/Sarajevo',
        364 => 'Europe/Saratov',
        365 => 'Europe/Simferopol',
        366 => 'Europe/Skopje',
        367 => 'Europe/Sofia',
        368 => 'Europe/Stockholm',
        369 => 'Europe/Tallinn',
        370 => 'Europe/Tirane',
        371 => 'Europe/Ulyanovsk',
        372 => 'Europe/Uzhgorod',
        373 => 'Europe/Vaduz',
        374 => 'Europe/Vatican',
        375 => 'Europe/Vienna',
        376 => 'Europe/Vilnius',
        377 => 'Europe/Volgograd',
        378 => 'Europe/Warsaw',
        379 => 'Europe/Zagreb',
        380 => 'Europe/Zaporozhye',
        381 => 'Europe/Zurich',
        382 => 'Indian/Antananarivo',
        383 => 'Indian/Chagos',
        384 => 'Indian/Christmas',
        385 => 'Indian/Cocos',
        386 => 'Indian/Comoro',
        387 => 'Indian/Kerguelen',
        388 => 'Indian/Mahe',
        389 => 'Indian/Maldives',
        390 => 'Indian/Mauritius',
        391 => 'Indian/Mayotte',
        392 => 'Indian/Reunion',
        393 => 'MST7MDT',
        394 => 'PST8PDT',
        395 => 'Pacific/Apia',
        396 => 'Pacific/Auckland',
        397 => 'Pacific/Bougainville',
        398 => 'Pacific/Chatham',
        399 => 'Pacific/Easter',
        400 => 'Pacific/Efate',
        401 => 'Pacific/Enderbury',
        402 => 'Pacific/Fakaofo',
        403 => 'Pacific/Fiji',
        404 => 'Pacific/Funafuti',
        405 => 'Pacific/Galapagos',
        406 => 'Pacific/Gambier',
        407 => 'Pacific/Guadalcanal',
        408 => 'Pacific/Guam',
        409 => 'Pacific/Honolulu',
        410 => 'Pacific/Johnston',
        411 => 'Pacific/Kiritimati',
        412 => 'Pacific/Kosrae',
        413 => 'Pacific/Kwajalein',
        414 => 'Pacific/Majuro',
        415 => 'Pacific/Marquesas',
        416 => 'Pacific/Midway',
        417 => 'Pacific/Nauru',
        418 => 'Pacific/Niue',
        419 => 'Pacific/Norfolk',
        420 => 'Pacific/Noumea',
        421 => 'Pacific/Pago_Pago',
        422 => 'Pacific/Palau',
        423 => 'Pacific/Pitcairn',
        424 => 'Pacific/Ponape',
        425 => 'Pacific/Port_Moresby',
        426 => 'Pacific/Rarotonga',
        427 => 'Pacific/Saipan',
        428 => 'Pacific/Tahiti',
        429 => 'Pacific/Tarawa',
        430 => 'Pacific/Tongatapu',
        431 => 'Pacific/Truk',
        432 => 'Pacific/Wake',
        433 => 'Pacific/Wallis',
    ],
    'ZoneToCountry' => [
        '' => 'MX',
        'Africa/Abidjan' => 'CI',
        'Africa/Accra' => 'GH',
        'Africa/Addis_Ababa' => 'ET',
        'Africa/Algiers' => 'DZ',
        'Africa/Asmera' => 'ER',
        'Africa/Bamako' => 'ML',
        'Africa/Bangui' => 'CF',
        'Africa/Banjul' => 'GM',
        'Africa/Bissau' => 'GW',
        'Africa/Blantyre' => 'MW',
        'Africa/Brazzaville' => 'CG',
        'Africa/Bujumbura' => 'BI',
        'Africa/Cairo' => 'EG',
        'Africa/Casablanca' => 'MA',
        'Africa/Ceuta' => 'ES',
        'Africa/Conakry' => 'GN',
        'Africa/Dakar' => 'SN',
        'Africa/Dar_es_Salaam' => 'TZ',
        'Africa/Djibouti' => 'DJ',
        'Africa/Douala' => 'CM',
        'Africa/El_Aaiun' => 'EH',
        'Africa/Freetown' => 'SL',
        'Africa/Gaborone' => 'BW',
        'Africa/Harare' => 'ZW',
        'Africa/Johannesburg' => 'ZA',
        'Africa/Juba' => 'SS',
        'Africa/Kampala' => 'UG',
        'Africa/Khartoum' => 'SD',
        'Africa/Kigali' => 'RW',
        'Africa/Kinshasa' => 'CD',
        'Africa/Lagos' => 'NG',
        'Africa/Libreville' => 'GA',
        'Africa/Lome' => 'TG',
        'Africa/Luanda' => 'AO',
        'Africa/Lubumbashi' => 'CD',
        'Africa/Lusaka' => 'ZM',
        'Africa/Malabo' => 'GQ',
        'Africa/Maputo' => 'MZ',
        'Africa/Maseru' => 'LS',
        'Africa/Mbabane' => 'SZ',
        'Africa/Mogadishu' => 'SO',
        'Africa/Monrovia' => 'LR',
        'Africa/Nairobi' => 'KE',
        'Africa/Ndjamena' => 'TD',
        'Africa/Niamey' => 'NE',
        'Africa/Nouakchott' => 'MR',
        'Africa/Ouagadougou' => 'BF',
        'Africa/Porto-Novo' => 'BJ',
        'Africa/Sao_Tome' => 'ST',
        'Africa/Tripoli' => 'LY',
        'Africa/Tunis' => 'TN',
        'Africa/Windhoek' => 'NA',
        'America/Adak' => 'US',
        'America/Anchorage' => 'US',
        'America/Anguilla' => 'AI',
        'America/Antigua' => 'AG',
        'America/Araguaina' => 'BR',
        'America/Argentina/La_Rioja' => 'AR',
        'America/Argentina/Rio_Gallegos' => 'AR',
        'America/Argentina/Salta' => 'AR',
        'America/Argentina/San_Juan' => 'AR',
        'America/Argentina/San_Luis' => 'AR',
        'America/Argentina/Tucuman' => 'AR',
        'America/Argentina/Ushuaia' => 'AR',
        'America/Aruba' => 'AW',
        'America/Asuncion' => 'PY',
        'America/Bahia' => 'BR',
        'America/Bahia_Banderas' => 'MX',
        'America/Barbados' => 'BB',
        'America/Belem' => 'BR',
        'America/Belize' => 'BZ',
        'America/Blanc-Sablon' => 'CA',
        'America/Boa_Vista' => 'BR',
        'America/Bogota' => 'CO',
        'America/Boise' => 'US',
        'America/Buenos_Aires' => 'AR',
        'America/Cambridge_Bay' => 'CA',
        'America/Campo_Grande' => 'BR',
        'America/Cancun' => 'MX',
        'America/Caracas' => 'VE',
        'America/Catamarca' => 'AR',
        'America/Cayenne' => 'GF',
        'America/Cayman' => 'KY',
        'America/Chicago' => 'US',
        'America/Chihuahua' => 'MX',
        'America/Ciudad_Juarez' => 'MX',
        'America/Coral_Harbour' => 'CA',
        'America/Cordoba' => 'AR',
        'America/Costa_Rica' => 'CR',
        'America/Creston' => 'CA',
        'America/Cuiaba' => 'BR',
        'America/Curacao' => 'CW',
        'America/Danmarkshavn' => 'GL',
        'America/Dawson' => 'CA',
        'America/Dawson_Creek' => 'CA',
        'America/Denver' => 'US',
        'America/Detroit' => 'US',
        'America/Dominica' => 'DM',
        'America/Edmonton' => 'CA',
        'America/Eirunepe' => 'BR',
        'America/El_Salvador' => 'SV',
        'America/Fort_Nelson' => 'CA',
        'America/Fortaleza' => 'BR',
        'America/Glace_Bay' => 'CA',
        'America/Godthab' => 'GL',
        'America/Goose_Bay' => 'CA',
        'America/Grand_Turk' => 'TC',
        'America/Grenada' => 'GD',
        'America/Guadeloupe' => 'GP',
        'America/Guatemala' => 'GT',
        'America/Guayaquil' => 'EC',
        'America/Guyana' => 'GY',
        'America/Halifax' => 'CA',
        'America/Havana' => 'CU',
        'America/Hermosillo' => 'MX',
        'America/Indiana/Knox' => 'US',
        'America/Indiana/Marengo' => 'US',
        'America/Indiana/Petersburg' => 'US',
        'America/Indiana/Tell_City' => 'US',
        'America/Indiana/Vevay' => 'US',
        'America/Indiana/Vincennes' => 'US',
        'America/Indiana/Winamac' => 'US',
        'America/Indianapolis' => 'US',
        'America/Inuvik' => 'CA',
        'America/Iqaluit' => 'CA',
        'America/Jamaica' => 'JM',
        'America/Jujuy' => 'AR',
        'America/Juneau' => 'US',
        'America/Kentucky/Monticello' => 'US',
        'America/Kralendijk' => 'BQ',
        'America/La_Paz' => 'BO',
        'America/Lima' => 'PE',
        'America/Los_Angeles' => 'US',
        'America/Louisville' => 'US',
        'America/Lower_Princes' => 'SX',
        'America/Maceio' => 'BR',
        'America/Managua' => 'NI',
        'America/Manaus' => 'BR',
        'America/Marigot' => 'MF',
        'America/Martinique' => 'MQ',
        'America/Matamoros' => 'MX',
        'America/Mazatlan' => 'MX',
        'America/Mendoza' => 'AR',
        'America/Menominee' => 'US',
        'America/Merida' => 'MX',
        'America/Metlakatla' => 'US',
        'America/Mexico_City' => 'MX',
        'America/Miquelon' => 'PM',
        'America/Moncton' => 'CA',
        'America/Monterrey' => 'MX',
        'America/Montevideo' => 'UY',
        'America/Montreal' => 'CA',
        'America/Montserrat' => 'MS',
        'America/Nassau' => 'BS',
        'America/New_York' => 'US',
        'America/Nipigon' => 'CA',
        'America/Nome' => 'US',
        'America/Noronha' => 'BR',
        'America/North_Dakota/Beulah' => 'US',
        'America/North_Dakota/Center' => 'US',
        'America/North_Dakota/New_Salem' => 'US',
        'America/Ojinaga' => 'MX',
        'America/Panama' => 'PA',
        'America/Pangnirtung' => 'CA',
        'America/Paramaribo' => 'SR',
        'America/Phoenix' => 'US',
        'America/Port-au-Prince' => 'HT',
        'America/Port_of_Spain' => 'TT',
        'America/Porto_Velho' => 'BR',
        'America/Puerto_Rico' => 'PR',
        'America/Punta_Arenas' => 'CL',
        'America/Rainy_River' => 'CA',
        'America/Rankin_Inlet' => 'CA',
        'America/Recife' => 'BR',
        'America/Regina' => 'CA',
        'America/Resolute' => 'CA',
        'America/Rio_Branco' => 'BR',
        'America/Santa_Isabel' => 'MX',
        'America/Santarem' => 'BR',
        'America/Santiago' => 'CL',
        'America/Santo_Domingo' => 'DO',
        'America/Sao_Paulo' => 'BR',
        'America/Scoresbysund' => 'GL',
        'America/Sitka' => 'US',
        'America/St_Barthelemy' => 'BL',
        'America/St_Johns' => 'CA',
        'America/St_Kitts' => 'KN',
        'America/St_Lucia' => 'LC',
        'America/St_Thomas' => 'VI',
        'America/St_Vincent' => 'VC',
        'America/Swift_Current' => 'CA',
        'America/Tegucigalpa' => 'HN',
        'America/Thule' => 'GL',
        'America/Thunder_Bay' => 'CA',
        'America/Tijuana' => 'MX',
        'America/Toronto' => 'CA',
        'America/Tortola' => 'VG',
        'America/Vancouver' => 'CA',
        'America/Whitehorse' => 'CA',
        'America/Winnipeg' => 'CA',
        'America/Yakutat' => 'US',
        'America/Yellowknife' => 'CA',
        'Antarctica/Casey' => 'AQ',
        'Antarctica/Davis' => 'AQ',
        'Antarctica/DumontDUrville' => 'AQ',
        'Antarctica/Macquarie' => 'AU',
        'Antarctica/Mawson' => 'AQ',
        'Antarctica/McMurdo' => 'AQ',
        'Antarctica/Palmer' => 'AQ',
        'Antarctica/Rothera' => 'AQ',
        'Antarctica/Syowa' => 'AQ',
        'Antarctica/Vostok' => 'AQ',
        'Arctic/Longyearbyen' => 'SJ',
        'Asia/Aden' => 'YE',
        'Asia/Almaty' => 'KZ',
        'Asia/Amman' => 'JO',
        'Asia/Anadyr' => 'RU',
        'Asia/Aqtau' => 'KZ',
        'Asia/Aqtobe' => 'KZ',
        'Asia/Ashgabat' => 'TM',
        'Asia/Atyrau' => 'KZ',
        'Asia/Baghdad' => 'IQ',
        'Asia/Bahrain' => 'BH',
        'Asia/Baku' => 'AZ',
        'Asia/Bangkok' => 'TH',
        'Asia/Barnaul' => 'RU',
        'Asia/Beirut' => 'LB',
        'Asia/Bishkek' => 'KG',
        'Asia/Brunei' => 'BN',
        'Asia/Calcutta' => 'IN',
        'Asia/Chita' => 'RU',
        'Asia/Choibalsan' => 'MN',
        'Asia/Colombo' => 'LK',
        'Asia/Damascus' => 'SY',
        'Asia/Dhaka' => 'BD',
        'Asia/Dili' => 'TL',
        'Asia/Dubai' => 'AE',
        'Asia/Dushanbe' => 'TJ',
        'Asia/Famagusta' => 'CY',
        'Asia/Gaza' => 'PS',
        'Asia/Hebron' => 'PS',
        'Asia/Hong_Kong' => 'HK',
        'Asia/Hovd' => 'MN',
        'Asia/Irkutsk' => 'RU',
        'Asia/Jakarta' => 'ID',
        'Asia/Jayapura' => 'ID',
        'Asia/Jerusalem' => 'IL',
        'Asia/Kabul' => 'AF',
        'Asia/Kamchatka' => 'RU',
        'Asia/Karachi' => 'PK',
        'Asia/Katmandu' => 'NP',
        'Asia/Khandyga' => 'RU',
        'Asia/Krasnoyarsk' => 'RU',
        'Asia/Kuala_Lumpur' => 'MY',
        'Asia/Kuching' => 'MY',
        'Asia/Kuwait' => 'KW',
        'Asia/Macau' => 'MO',
        'Asia/Magadan' => 'RU',
        'Asia/Makassar' => 'ID',
        'Asia/Manila' => 'PH',
        'Asia/Muscat' => 'OM',
        'Asia/Nicosia' => 'CY',
        'Asia/Novokuznetsk' => 'RU',
        'Asia/Novosibirsk' => 'RU',
        'Asia/Omsk' => 'RU',
        'Asia/Oral' => 'KZ',
        'Asia/Phnom_Penh' => 'KH',
        'Asia/Pontianak' => 'ID',
        'Asia/Pyongyang' => 'KP',
        'Asia/Qatar' => 'QA',
        'Asia/Qostanay' => 'KZ',
        'Asia/Qyzylorda' => 'KZ',
        'Asia/Rangoon' => 'MM',
        'Asia/Riyadh' => 'SA',
        'Asia/Saigon' => 'VN',
        'Asia/Sakhalin' => 'RU',
        'Asia/Samarkand' => 'UZ',
        'Asia/Seoul' => 'KR',
        'Asia/Shanghai' => 'CN',
        'Asia/Singapore' => 'SG',
        'Asia/Srednekolymsk' => 'RU',
        'Asia/Taipei' => 'TW',
        'Asia/Tashkent' => 'UZ',
        'Asia/Tbilisi' => 'GE',
        'Asia/Tehran' => 'IR',
        'Asia/Thimphu' => 'BT',
        'Asia/Tokyo' => 'JP',
        'Asia/Tomsk' => 'RU',
        'Asia/Ulaanbaatar' => 'MN',
        'Asia/Urumqi' => 'CN',
        'Asia/Ust-Nera' => 'RU',
        'Asia/Vientiane' => 'LA',
        'Asia/Vladivostok' => 'RU',
        'Asia/Yakutsk' => 'RU',
        'Asia/Yekaterinburg' => 'RU',
        'Asia/Yerevan' => 'AM',
        'Atlantic/Azores' => 'PT',
        'Atlantic/Bermuda' => 'BM',
        'Atlantic/Canary' => 'ES',
        'Atlantic/Cape_Verde' => 'CV',
        'Atlantic/Faeroe' => 'FO',
        'Atlantic/Madeira' => 'PT',
        'Atlantic/Reykjavik' => 'IS',
        'Atlantic/South_Georgia' => 'GS',
        'Atlantic/St_Helena' => 'SH',
        'Atlantic/Stanley' => 'FK',
        'Australia/Adelaide' => 'AU',
        'Australia/Brisbane' => 'AU',
        'Australia/Broken_Hill' => 'AU',
        'Australia/Currie' => 'AU',
        'Australia/Darwin' => 'AU',
        'Australia/Eucla' => 'AU',
        'Australia/Hobart' => 'AU',
        'Australia/Lindeman' => 'AU',
        'Australia/Lord_Howe' => 'AU',
        'Australia/Melbourne' => 'AU',
        'Australia/Perth' => 'AU',
        'Australia/Sydney' => 'AU',
        'Europe/Amsterdam' => 'NL',
        'Europe/Andorra' => 'AD',
        'Europe/Astrakhan' => 'RU',
        'Europe/Athens' => 'GR',
        'Europe/Belgrade' => 'RS',
        'Europe/Berlin' => 'DE',
        'Europe/Bratislava' => 'SK',
        'Europe/Brussels' => 'BE',
        'Europe/Bucharest' => 'RO',
        'Europe/Budapest' => 'HU',
        'Europe/Busingen' => 'DE',
        'Europe/Chisinau' => 'MD',
        'Europe/Copenhagen' => 'DK',
        'Europe/Dublin' => 'IE',
        'Europe/Gibraltar' => 'GI',
        'Europe/Guernsey' => 'GG',
        'Europe/Helsinki' => 'FI',
        'Europe/Isle_of_Man' => 'IM',
        'Europe/Istanbul' => 'TR',
        'Europe/Jersey' => 'JE',
        'Europe/Kaliningrad' => 'RU',
        'Europe/Kiev' => 'UA',
        'Europe/Kirov' => 'RU',
        'Europe/Lisbon' => 'PT',
        'Europe/Ljubljana' => 'SI',
        'Europe/London' => 'GB',
        'Europe/Luxembourg' => 'LU',
        'Europe/Madrid' => 'ES',
        'Europe/Malta' => 'MT',
        'Europe/Mariehamn' => 'AX',
        'Europe/Minsk' => 'BY',
        'Europe/Monaco' => 'MC',
        'Europe/Moscow' => 'RU',
        'Europe/Oslo' => 'NO',
        'Europe/Paris' => 'FR',
        'Europe/Podgorica' => 'ME',
        'Europe/Prague' => 'CZ',
        'Europe/Riga' => 'LV',
        'Europe/Rome' => 'IT',
        'Europe/Samara' => 'RU',
        'Europe/San_Marino' => 'SM',
        'Europe/Sarajevo' => 'BA',
        'Europe/Saratov' => 'RU',
        'Europe/Simferopol' => 'UA',
        'Europe/Skopje' => 'MK',
        'Europe/Sofia' => 'BG',
        'Europe/Stockholm' => 'SE',
        'Europe/Tallinn' => 'EE',
        'Europe/Tirane' => 'AL',
        'Europe/Ulyanovsk' => 'RU',
        'Europe/Uzhgorod' => 'UA',
        'Europe/Vaduz' => 'LI',
        'Europe/Vatican' => 'VA',
        'Europe/Vienna' => 'AT',
        'Europe/Vilnius' => 'LT',
        'Europe/Volgograd' => 'RU',
        'Europe/Warsaw' => 'PL',
        'Europe/Zagreb' => 'HR',
        'Europe/Zaporozhye' => 'UA',
        'Europe/Zurich' => 'CH',
        'Indian/Antananarivo' => 'MG',
        'Indian/Chagos' => 'IO',
        'Indian/Christmas' => 'CX',
        'Indian/Cocos' => 'CC',
        'Indian/Comoro' => 'KM',
        'Indian/Kerguelen' => 'TF',
        'Indian/Mahe' => 'SC',
        'Indian/Maldives' => 'MV',
        'Indian/Mauritius' => 'MU',
        'Indian/Mayotte' => 'YT',
        'Indian/Reunion' => 'RE',
        'Pacific/Apia' => 'WS',
        'Pacific/Auckland' => 'NZ',
        'Pacific/Bougainville' => 'PG',
        'Pacific/Chatham' => 'NZ',
        'Pacific/Easter' => 'CL',
        'Pacific/Efate' => 'VU',
        'Pacific/Enderbury' => 'KI',
        'Pacific/Fakaofo' => 'TK',
        'Pacific/Fiji' => 'FJ',
        'Pacific/Funafuti' => 'TV',
        'Pacific/Galapagos' => 'EC',
        'Pacific/Gambier' => 'PF',
        'Pacific/Guadalcanal' => 'SB',
        'Pacific/Guam' => 'GU',
        'Pacific/Honolulu' => 'US',
        'Pacific/Johnston' => 'UM',
        'Pacific/Kiritimati' => 'KI',
        'Pacific/Kosrae' => 'FM',
        'Pacific/Kwajalein' => 'MH',
        'Pacific/Majuro' => 'MH',
        'Pacific/Marquesas' => 'PF',
        'Pacific/Midway' => 'UM',
        'Pacific/Nauru' => 'NR',
        'Pacific/Niue' => 'NU',
        'Pacific/Norfolk' => 'NF',
        'Pacific/Noumea' => 'NC',
        'Pacific/Pago_Pago' => 'AS',
        'Pacific/Palau' => 'PW',
        'Pacific/Pitcairn' => 'PN',
        'Pacific/Ponape' => 'FM',
        'Pacific/Port_Moresby' => 'PG',
        'Pacific/Rarotonga' => 'CK',
        'Pacific/Saipan' => 'MP',
        'Pacific/Tahiti' => 'PF',
        'Pacific/Tarawa' => 'KI',
        'Pacific/Tongatapu' => 'TO',
        'Pacific/Truk' => 'FM',
        'Pacific/Wake' => 'UM',
        'Pacific/Wallis' => 'WF',
    ],
    'CountryToZone' => [
        'AD' => [
            0 => 'Europe/Andorra',
        ],
        'AE' => [
            0 => 'Asia/Dubai',
        ],
        'AF' => [
            0 => 'Asia/Kabul',
        ],
        'AG' => [
            0 => 'America/Antigua',
        ],
        'AI' => [
            0 => 'America/Anguilla',
        ],
        'AL' => [
            0 => 'Europe/Tirane',
        ],
        'AM' => [
            0 => 'Asia/Yerevan',
        ],
        'AO' => [
            0 => 'Africa/Luanda',
        ],
        'AQ' => [
            0 => 'Antarctica/Casey',
            1 => 'Antarctica/Davis',
            2 => 'Antarctica/DumontDUrville',
            3 => 'Antarctica/Mawson',
            4 => 'Antarctica/McMurdo',
            5 => 'Antarctica/Palmer',
            6 => 'Antarctica/Rothera',
            7 => 'Antarctica/Syowa',
            8 => 'Antarctica/Vostok',
        ],
        'AR' => [
            0 => 'America/Argentina/La_Rioja',
            1 => 'America/Argentina/Rio_Gallegos',
            2 => 'America/Argentina/Salta',
            3 => 'America/Argentina/San_Juan',
            4 => 'America/Argentina/San_Luis',
            5 => 'America/Argentina/Tucuman',
            6 => 'America/Argentina/Ushuaia',
            7 => 'America/Buenos_Aires',
            8 => 'America/Catamarca',
            9 => 'America/Cordoba',
            10 => 'America/Jujuy',
            11 => 'America/Mendoza',
        ],
        'AS' => [
            0 => 'Pacific/Pago_Pago',
        ],
        'AT' => [
            0 => 'Europe/Vienna',
        ],
        'AU' => [
            0 => 'Antarctica/Macquarie',
            1 => 'Australia/Adelaide',
            2 => 'Australia/Brisbane',
            3 => 'Australia/Broken_Hill',
            4 => 'Australia/Currie',
            5 => 'Australia/Darwin',
            6 => 'Australia/Eucla',
            7 => 'Australia/Hobart',
            8 => 'Australia/Lindeman',
            9 => 'Australia/Lord_Howe',
            10 => 'Australia/Melbourne',
            11 => 'Australia/Perth',
            12 => 'Australia/Sydney',
        ],
        'AW' => [
            0 => 'America/Aruba',
        ],
        'AX' => [
            0 => 'Europe/Mariehamn',
        ],
        'AZ' => [
            0 => 'Asia/Baku',
        ],
        'BA' => [
            0 => 'Europe/Sarajevo',
        ],
        'BB' => [
            0 => 'America/Barbados',
        ],
        'BD' => [
            0 => 'Asia/Dhaka',
        ],
        'BE' => [
            0 => 'Europe/Brussels',
        ],
        'BF' => [
            0 => 'Africa/Ouagadougou',
        ],
        'BG' => [
            0 => 'Europe/Sofia',
        ],
        'BH' => [
            0 => 'Asia/Bahrain',
        ],
        'BI' => [
            0 => 'Africa/Bujumbura',
        ],
        'BJ' => [
            0 => 'Africa/Porto-Novo',
        ],
        'BL' => [
            0 => 'America/St_Barthelemy',
        ],
        'BM' => [
            0 => 'Atlantic/Bermuda',
        ],
        'BN' => [
            0 => 'Asia/Brunei',
        ],
        'BO' => [
            0 => 'America/La_Paz',
        ],
        'BQ' => [
            0 => 'America/Kralendijk',
        ],
        'BR' => [
            0 => 'America/Araguaina',
            1 => 'America/Bahia',
            2 => 'America/Belem',
            3 => 'America/Boa_Vista',
            4 => 'America/Campo_Grande',
            5 => 'America/Cuiaba',
            6 => 'America/Eirunepe',
            7 => 'America/Fortaleza',
            8 => 'America/Maceio',
            9 => 'America/Manaus',
            10 => 'America/Noronha',
            11 => 'America/Porto_Velho',
            12 => 'America/Recife',
            13 => 'America/Rio_Branco',
            14 => 'America/Santarem',
            15 => 'America/Sao_Paulo',
        ],
        'BS' => [
            0 => 'America/Nassau',
        ],
        'BT' => [
            0 => 'Asia/Thimphu',
        ],
        'BW' => [
            0 => 'Africa/Gaborone',
        ],
        'BY' => [
            0 => 'Europe/Minsk',
        ],
        'BZ' => [
            0 => 'America/Belize',
        ],
        'CA' => [
            0 => 'America/Blanc-Sablon',
            1 => 'America/Cambridge_Bay',
            2 => 'America/Coral_Harbour',
            3 => 'America/Creston',
            4 => 'America/Dawson',
            5 => 'America/Dawson_Creek',
            6 => 'America/Edmonton',
            7 => 'America/Fort_Nelson',
            8 => 'America/Glace_Bay',
            9 => 'America/Goose_Bay',
            10 => 'America/Halifax',
            11 => 'America/Inuvik',
            12 => 'America/Iqaluit',
            13 => 'America/Moncton',
            14 => 'America/Montreal',
            15 => 'America/Nipigon',
            16 => 'America/Pangnirtung',
            17 => 'America/Rainy_River',
            18 => 'America/Rankin_Inlet',
            19 => 'America/Regina',
            20 => 'America/Resolute',
            21 => 'America/St_Johns',
            22 => 'America/Swift_Current',
            23 => 'America/Thunder_Bay',
            24 => 'America/Toronto',
            25 => 'America/Vancouver',
            26 => 'America/Whitehorse',
            27 => 'America/Winnipeg',
            28 => 'America/Yellowknife',
        ],
        'CC' => [
            0 => 'Indian/Cocos',
        ],
        'CD' => [
            0 => 'Africa/Kinshasa',
            1 => 'Africa/Lubumbashi',
        ],
        'CF' => [
            0 => 'Africa/Bangui',
        ],
        'CG' => [
            0 => 'Africa/Brazzaville',
        ],
        'CH' => [
            0 => 'Europe/Zurich',
        ],
        'CI' => [
            0 => 'Africa/Abidjan',
        ],
        'CK' => [
            0 => 'Pacific/Rarotonga',
        ],
        'CL' => [
            0 => 'America/Punta_Arenas',
            1 => 'America/Santiago',
            2 => 'Pacific/Easter',
        ],
        'CM' => [
            0 => 'Africa/Douala',
        ],
        'CN' => [
            0 => 'Asia/Shanghai',
            1 => 'Asia/Urumqi',
        ],
        'CO' => [
            0 => 'America/Bogota',
        ],
        'CR' => [
            0 => 'America/Costa_Rica',
        ],
        'CU' => [
            0 => 'America/Havana',
        ],
        'CV' => [
            0 => 'Atlantic/Cape_Verde',
        ],
        'CW' => [
            0 => 'America/Curacao',
        ],
        'CX' => [
            0 => 'Indian/Christmas',
        ],
        'CY' => [
            0 => 'Asia/Famagusta',
            1 => 'Asia/Nicosia',
        ],
        'CZ' => [
            0 => 'Europe/Prague',
        ],
        'DE' => [
            0 => 'Europe/Berlin',
            1 => 'Europe/Busingen',
        ],
        'DJ' => [
            0 => 'Africa/Djibouti',
        ],
        'DK' => [
            0 => 'Europe/Copenhagen',
        ],
        'DM' => [
            0 => 'America/Dominica',
        ],
        'DO' => [
            0 => 'America/Santo_Domingo',
        ],
        'DZ' => [
            0 => 'Africa/Algiers',
        ],
        'EC' => [
            0 => 'America/Guayaquil',
            1 => 'Pacific/Galapagos',
        ],
        'EE' => [
            0 => 'Europe/Tallinn',
        ],
        'EG' => [
            0 => 'Africa/Cairo',
        ],
        'EH' => [
            0 => 'Africa/El_Aaiun',
        ],
        'ER' => [
            0 => 'Africa/Asmera',
        ],
        'ES' => [
            0 => 'Africa/Ceuta',
            1 => 'Atlantic/Canary',
            2 => 'Europe/Madrid',
        ],
        'ET' => [
            0 => 'Africa/Addis_Ababa',
        ],
        'FI' => [
            0 => 'Europe/Helsinki',
        ],
        'FJ' => [
            0 => 'Pacific/Fiji',
        ],
        'FK' => [
            0 => 'Atlantic/Stanley',
        ],
        'FM' => [
            0 => 'Pacific/Kosrae',
            1 => 'Pacific/Ponape',
            2 => 'Pacific/Truk',
        ],
        'FO' => [
            0 => 'Atlantic/Faeroe',
        ],
        'FR' => [
            0 => 'Europe/Paris',
        ],
        'GA' => [
            0 => 'Africa/Libreville',
        ],
        'GB' => [
            0 => 'Europe/London',
        ],
        'GD' => [
            0 => 'America/Grenada',
        ],
        'GE' => [
            0 => 'Asia/Tbilisi',
        ],
        'GF' => [
            0 => 'America/Cayenne',
        ],
        'GG' => [
            0 => 'Europe/Guernsey',
        ],
        'GH' => [
            0 => 'Africa/Accra',
        ],
        'GI' => [
            0 => 'Europe/Gibraltar',
        ],
        'GL' => [
            0 => 'America/Danmarkshavn',
            1 => 'America/Godthab',
            2 => 'America/Scoresbysund',
            3 => 'America/Thule',
        ],
        'GM' => [
            0 => 'Africa/Banjul',
        ],
        'GN' => [
            0 => 'Africa/Conakry',
        ],
        'GP' => [
            0 => 'America/Guadeloupe',
        ],
        'GQ' => [
            0 => 'Africa/Malabo',
        ],
        'GR' => [
            0 => 'Europe/Athens',
        ],
        'GS' => [
            0 => 'Atlantic/South_Georgia',
        ],
        'GT' => [
            0 => 'America/Guatemala',
        ],
        'GU' => [
            0 => 'Pacific/Guam',
        ],
        'GW' => [
            0 => 'Africa/Bissau',
        ],
        'GY' => [
            0 => 'America/Guyana',
        ],
        'HK' => [
            0 => 'Asia/Hong_Kong',
        ],
        'HN' => [
            0 => 'America/Tegucigalpa',
        ],
        'HR' => [
            0 => 'Europe/Zagreb',
        ],
        'HT' => [
            0 => 'America/Port-au-Prince',
        ],
        'HU' => [
            0 => 'Europe/Budapest',
        ],
        'ID' => [
            0 => 'Asia/Jakarta',
            1 => 'Asia/Jayapura',
            2 => 'Asia/Makassar',
            3 => 'Asia/Pontianak',
        ],
        'IE' => [
            0 => 'Europe/Dublin',
        ],
        'IL' => [
            0 => 'Asia/Jerusalem',
        ],
        'IM' => [
            0 => 'Europe/Isle_of_Man',
        ],
        'IN' => [
            0 => 'Asia/Calcutta',
        ],
        'IO' => [
            0 => 'Indian/Chagos',
        ],
        'IQ' => [
            0 => 'Asia/Baghdad',
        ],
        'IR' => [
            0 => 'Asia/Tehran',
        ],
        'IS' => [
            0 => 'Atlantic/Reykjavik',
        ],
        'IT' => [
            0 => 'Europe/Rome',
        ],
        'JE' => [
            0 => 'Europe/Jersey',
        ],
        'JM' => [
            0 => 'America/Jamaica',
        ],
        'JO' => [
            0 => 'Asia/Amman',
        ],
        'JP' => [
            0 => 'Asia/Tokyo',
        ],
        'KE' => [
            0 => 'Africa/Nairobi',
        ],
        'KG' => [
            0 => 'Asia/Bishkek',
        ],
        'KH' => [
            0 => 'Asia/Phnom_Penh',
        ],
        'KI' => [
            0 => 'Pacific/Enderbury',
            1 => 'Pacific/Kiritimati',
            2 => 'Pacific/Tarawa',
        ],
        'KM' => [
            0 => 'Indian/Comoro',
        ],
        'KN' => [
            0 => 'America/St_Kitts',
        ],
        'KP' => [
            0 => 'Asia/Pyongyang',
        ],
        'KR' => [
            0 => 'Asia/Seoul',
        ],
        'KW' => [
            0 => 'Asia/Kuwait',
        ],
        'KY' => [
            0 => 'America/Cayman',
        ],
        'KZ' => [
            0 => 'Asia/Almaty',
            1 => 'Asia/Aqtau',
            2 => 'Asia/Aqtobe',
            3 => 'Asia/Atyrau',
            4 => 'Asia/Oral',
            5 => 'Asia/Qostanay',
            6 => 'Asia/Qyzylorda',
        ],
        'LA' => [
            0 => 'Asia/Vientiane',
        ],
        'LB' => [
            0 => 'Asia/Beirut',
        ],
        'LC' => [
            0 => 'America/St_Lucia',
        ],
        'LI' => [
            0 => 'Europe/Vaduz',
        ],
        'LK' => [
            0 => 'Asia/Colombo',
        ],
        'LR' => [
            0 => 'Africa/Monrovia',
        ],
        'LS' => [
            0 => 'Africa/Maseru',
        ],
        'LT' => [
            0 => 'Europe/Vilnius',
        ],
        'LU' => [
            0 => 'Europe/Luxembourg',
        ],
        'LV' => [
            0 => 'Europe/Riga',
        ],
        'LY' => [
            0 => 'Africa/Tripoli',
        ],
        'MA' => [
            0 => 'Africa/Casablanca',
        ],
        'MC' => [
            0 => 'Europe/Monaco',
        ],
        'MD' => [
            0 => 'Europe/Chisinau',
        ],
        'ME' => [
            0 => 'Europe/Podgorica',
        ],
        'MF' => [
            0 => 'America/Marigot',
        ],
        'MG' => [
            0 => 'Indian/Antananarivo',
        ],
        'MH' => [
            0 => 'Pacific/Kwajalein',
            1 => 'Pacific/Majuro',
        ],
        'MK' => [
            0 => 'Europe/Skopje',
        ],
        'ML' => [
            0 => 'Africa/Bamako',
        ],
        'MM' => [
            0 => 'Asia/Rangoon',
        ],
        'MN' => [
            0 => 'Asia/Choibalsan',
            1 => 'Asia/Hovd',
            2 => 'Asia/Ulaanbaatar',
        ],
        'MO' => [
            0 => 'Asia/Macau',
        ],
        'MP' => [
            0 => 'Pacific/Saipan',
        ],
        'MQ' => [
            0 => 'America/Martinique',
        ],
        'MR' => [
            0 => 'Africa/Nouakchott',
        ],
        'MS' => [
            0 => 'America/Montserrat',
        ],
        'MT' => [
            0 => 'Europe/Malta',
        ],
        'MU' => [
            0 => 'Indian/Mauritius',
        ],
        'MV' => [
            0 => 'Indian/Maldives',
        ],
        'MW' => [
            0 => 'Africa/Blantyre',
        ],
        'MX' => [
            0 => '',
            1 => 'America/Bahia_Banderas',
            2 => 'America/Cancun',
            3 => 'America/Chihuahua',
            4 => 'America/Ciudad_Juarez',
            5 => 'America/Hermosillo',
            6 => 'America/Matamoros',
            7 => 'America/Mazatlan',
            8 => 'America/Merida',
            9 => 'America/Mexico_City',
            10 => 'America/Monterrey',
            11 => 'America/Ojinaga',
            12 => 'America/Santa_Isabel',
            13 => 'America/Tijuana',
        ],
        'MY' => [
            0 => 'Asia/Kuala_Lumpur',
            1 => 'Asia/Kuching',
        ],
        'MZ' => [
            0 => 'Africa/Maputo',
        ],
        'NA' => [
            0 => 'Africa/Windhoek',
        ],
        'NC' => [
            0 => 'Pacific/Noumea',
        ],
        'NE' => [
            0 => 'Africa/Niamey',
        ],
        'NF' => [
            0 => 'Pacific/Norfolk',
        ],
        'NG' => [
            0 => 'Africa/Lagos',
        ],
        'NI' => [
            0 => 'America/Managua',
        ],
        'NL' => [
            0 => 'Europe/Amsterdam',
        ],
        'NO' => [
            0 => 'Europe/Oslo',
        ],
        'NP' => [
            0 => 'Asia/Katmandu',
        ],
        'NR' => [
            0 => 'Pacific/Nauru',
        ],
        'NU' => [
            0 => 'Pacific/Niue',
        ],
        'NZ' => [
            0 => 'Pacific/Auckland',
            1 => 'Pacific/Chatham',
        ],
        'OM' => [
            0 => 'Asia/Muscat',
        ],
        'PA' => [
            0 => 'America/Panama',
        ],
        'PE' => [
            0 => 'America/Lima',
        ],
        'PF' => [
            0 => 'Pacific/Gambier',
            1 => 'Pacific/Marquesas',
            2 => 'Pacific/Tahiti',
        ],
        'PG' => [
            0 => 'Pacific/Bougainville',
            1 => 'Pacific/Port_Moresby',
        ],
        'PH' => [
            0 => 'Asia/Manila',
        ],
        'PK' => [
            0 => 'Asia/Karachi',
        ],
        'PL' => [
            0 => 'Europe/Warsaw',
        ],
        'PM' => [
            0 => 'America/Miquelon',
        ],
        'PN' => [
            0 => 'Pacific/Pitcairn',
        ],
        'PR' => [
            0 => 'America/Puerto_Rico',
        ],
        'PS' => [
            0 => 'Asia/Gaza',
            1 => 'Asia/Hebron',
        ],
        'PT' => [
            0 => 'Atlantic/Azores',
            1 => 'Atlantic/Madeira',
            2 => 'Europe/Lisbon',
        ],
        'PW' => [
            0 => 'Pacific/Palau',
        ],
        'PY' => [
            0 => 'America/Asuncion',
        ],
        'QA' => [
            0 => 'Asia/Qatar',
        ],
        'RE' => [
            0 => 'Indian/Reunion',
        ],
        'RO' => [
            0 => 'Europe/Bucharest',
        ],
        'RS' => [
            0 => 'Europe/Belgrade',
        ],
        'RU' => [
            0 => 'Asia/Anadyr',
            1 => 'Asia/Barnaul',
            2 => 'Asia/Chita',
            3 => 'Asia/Irkutsk',
            4 => 'Asia/Kamchatka',
            5 => 'Asia/Khandyga',
            6 => 'Asia/Krasnoyarsk',
            7 => 'Asia/Magadan',
            8 => 'Asia/Novokuznetsk',
            9 => 'Asia/Novosibirsk',
            10 => 'Asia/Omsk',
            11 => 'Asia/Sakhalin',
            12 => 'Asia/Srednekolymsk',
            13 => 'Asia/Tomsk',
            14 => 'Asia/Ust-Nera',
            15 => 'Asia/Vladivostok',
            16 => 'Asia/Yakutsk',
            17 => 'Asia/Yekaterinburg',
            18 => 'Europe/Astrakhan',
            19 => 'Europe/Kaliningrad',
            20 => 'Europe/Kirov',
            21 => 'Europe/Moscow',
            22 => 'Europe/Samara',
            23 => 'Europe/Saratov',
            24 => 'Europe/Ulyanovsk',
            25 => 'Europe/Volgograd',
        ],
        'RW' => [
            0 => 'Africa/Kigali',
        ],
        'SA' => [
            0 => 'Asia/Riyadh',
        ],
        'SB' => [
            0 => 'Pacific/Guadalcanal',
        ],
        'SC' => [
            0 => 'Indian/Mahe',
        ],
        'SD' => [
            0 => 'Africa/Khartoum',
        ],
        'SE' => [
            0 => 'Europe/Stockholm',
        ],
        'SG' => [
            0 => 'Asia/Singapore',
        ],
        'SH' => [
            0 => 'Atlantic/St_Helena',
        ],
        'SI' => [
            0 => 'Europe/Ljubljana',
        ],
        'SJ' => [
            0 => 'Arctic/Longyearbyen',
        ],
        'SK' => [
            0 => 'Europe/Bratislava',
        ],
        'SL' => [
            0 => 'Africa/Freetown',
        ],
        'SM' => [
            0 => 'Europe/San_Marino',
        ],
        'SN' => [
            0 => 'Africa/Dakar',
        ],
        'SO' => [
            0 => 'Africa/Mogadishu',
        ],
        'SR' => [
            0 => 'America/Paramaribo',
        ],
        'SS' => [
            0 => 'Africa/Juba',
        ],
        'ST' => [
            0 => 'Africa/Sao_Tome',
        ],
        'SV' => [
            0 => 'America/El_Salvador',
        ],
        'SX' => [
            0 => 'America/Lower_Princes',
        ],
        'SY' => [
            0 => 'Asia/Damascus',
        ],
        'SZ' => [
            0 => 'Africa/Mbabane',
        ],
        'TC' => [
            0 => 'America/Grand_Turk',
        ],
        'TD' => [
            0 => 'Africa/Ndjamena',
        ],
        'TF' => [
            0 => 'Indian/Kerguelen',
        ],
        'TG' => [
            0 => 'Africa/Lome',
        ],
        'TH' => [
            0 => 'Asia/Bangkok',
        ],
        'TJ' => [
            0 => 'Asia/Dushanbe',
        ],
        'TK' => [
            0 => 'Pacific/Fakaofo',
        ],
        'TL' => [
            0 => 'Asia/Dili',
        ],
        'TM' => [
            0 => 'Asia/Ashgabat',
        ],
        'TN' => [
            0 => 'Africa/Tunis',
        ],
        'TO' => [
            0 => 'Pacific/Tongatapu',
        ],
        'TR' => [
            0 => 'Europe/Istanbul',
        ],
        'TT' => [
            0 => 'America/Port_of_Spain',
        ],
        'TV' => [
            0 => 'Pacific/Funafuti',
        ],
        'TW' => [
            0 => 'Asia/Taipei',
        ],
        'TZ' => [
            0 => 'Africa/Dar_es_Salaam',
        ],
        'UA' => [
            0 => 'Europe/Kiev',
            1 => 'Europe/Simferopol',
            2 => 'Europe/Uzhgorod',
            3 => 'Europe/Zaporozhye',
        ],
        'UG' => [
            0 => 'Africa/Kampala',
        ],
        'UM' => [
            0 => 'Pacific/Johnston',
            1 => 'Pacific/Midway',
            2 => 'Pacific/Wake',
        ],
        'US' => [
            0 => 'America/Adak',
            1 => 'America/Anchorage',
            2 => 'America/Boise',
            3 => 'America/Chicago',
            4 => 'America/Denver',
            5 => 'America/Detroit',
            6 => 'America/Indiana/Knox',
            7 => 'America/Indiana/Marengo',
            8 => 'America/Indiana/Petersburg',
            9 => 'America/Indiana/Tell_City',
            10 => 'America/Indiana/Vevay',
            11 => 'America/Indiana/Vincennes',
            12 => 'America/Indiana/Winamac',
            13 => 'America/Indianapolis',
            14 => 'America/Juneau',
            15 => 'America/Kentucky/Monticello',
            16 => 'America/Los_Angeles',
            17 => 'America/Louisville',
            18 => 'America/Menominee',
            19 => 'America/Metlakatla',
            20 => 'America/New_York',
            21 => 'America/Nome',
            22 => 'America/North_Dakota/Beulah',
            23 => 'America/North_Dakota/Center',
            24 => 'America/North_Dakota/New_Salem',
            25 => 'America/Phoenix',
            26 => 'America/Sitka',
            27 => 'America/Yakutat',
            28 => 'Pacific/Honolulu',
        ],
        'UY' => [
            0 => 'America/Montevideo',
        ],
        'UZ' => [
            0 => 'Asia/Samarkand',
            1 => 'Asia/Tashkent',
        ],
        'VA' => [
            0 => 'Europe/Vatican',
        ],
        'VC' => [
            0 => 'America/St_Vincent',
        ],
        'VE' => [
            0 => 'America/Caracas',
        ],
        'VG' => [
            0 => 'America/Tortola',
        ],
        'VI' => [
            0 => 'America/St_Thomas',
        ],
        'VN' => [
            0 => 'Asia/Saigon',
        ],
        'VU' => [
            0 => 'Pacific/Efate',
        ],
        'WF' => [
            0 => 'Pacific/Wallis',
        ],
        'WS' => [
            0 => 'Pacific/Apia',
        ],
        'YE' => [
            0 => 'Asia/Aden',
        ],
        'YT' => [
            0 => 'Indian/Mayotte',
        ],
        'ZA' => [
            0 => 'Africa/Johannesburg',
        ],
        'ZM' => [
            0 => 'Africa/Lusaka',
        ],
        'ZW' => [
            0 => 'Africa/Harare',
        ],
    ],
];
